# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardCreateInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'applied_filter': 'str',
        'background_color': 'str',
        'columns': 'int',
        'description': 'str',
        'name': 'str',
        'row_height': 'int',
        'scoped_to': 'str',
        'timezone': 'str'
    }

    attribute_map = {
        'applied_filter': 'appliedFilter',
        'background_color': 'backgroundColor',
        'columns': 'columns',
        'description': 'description',
        'name': 'name',
        'row_height': 'rowHeight',
        'scoped_to': 'scopedTo',
        'timezone': 'timezone'
    }

    def __init__(self, applied_filter=None, background_color=None, columns=None, description=None, name=None, row_height=None, scoped_to=None, timezone=None):
        """
        BoardCreateInputV1 - a model defined in Swagger
        """

        self._applied_filter = None
        self._background_color = None
        self._columns = None
        self._description = None
        self._name = None
        self._row_height = None
        self._scoped_to = None
        self._timezone = None

        if applied_filter is not None:
          self.applied_filter = applied_filter
        if background_color is not None:
          self.background_color = background_color
        if columns is not None:
          self.columns = columns
        if description is not None:
          self.description = description
        if name is not None:
          self.name = name
        if row_height is not None:
          self.row_height = row_height
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if timezone is not None:
          self.timezone = timezone

    @property
    def applied_filter(self):
        """
        Gets the applied_filter of this BoardCreateInputV1.
        The applied filter configuration as JSON

        :return: The applied_filter of this BoardCreateInputV1.
        :rtype: str
        """
        return self._applied_filter

    @applied_filter.setter
    def applied_filter(self, applied_filter):
        """
        Sets the applied_filter of this BoardCreateInputV1.
        The applied filter configuration as JSON

        :param applied_filter: The applied_filter of this BoardCreateInputV1.
        :type: str
        """

        self._applied_filter = applied_filter

    @property
    def background_color(self):
        """
        Gets the background_color of this BoardCreateInputV1.
        The background color of the board (CSS color value)

        :return: The background_color of this BoardCreateInputV1.
        :rtype: str
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this BoardCreateInputV1.
        The background color of the board (CSS color value)

        :param background_color: The background_color of this BoardCreateInputV1.
        :type: str
        """

        self._background_color = background_color

    @property
    def columns(self):
        """
        Gets the columns of this BoardCreateInputV1.
        The number of columns in the board grid

        :return: The columns of this BoardCreateInputV1.
        :rtype: int
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this BoardCreateInputV1.
        The number of columns in the board grid

        :param columns: The columns of this BoardCreateInputV1.
        :type: int
        """

        self._columns = columns

    @property
    def description(self):
        """
        Gets the description of this BoardCreateInputV1.
        The description of the board

        :return: The description of this BoardCreateInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BoardCreateInputV1.
        The description of the board

        :param description: The description of this BoardCreateInputV1.
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """
        Gets the name of this BoardCreateInputV1.
        The name of the board

        :return: The name of this BoardCreateInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BoardCreateInputV1.
        The name of the board

        :param name: The name of this BoardCreateInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def row_height(self):
        """
        Gets the row_height of this BoardCreateInputV1.
        The height of each row in grid units

        :return: The row_height of this BoardCreateInputV1.
        :rtype: int
        """
        return self._row_height

    @row_height.setter
    def row_height(self, row_height):
        """
        Sets the row_height of this BoardCreateInputV1.
        The height of each row in grid units

        :param row_height: The row_height of this BoardCreateInputV1.
        :type: int
        """

        self._row_height = row_height

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this BoardCreateInputV1.
        The ID of the workbook to which the board will be scoped

        :return: The scoped_to of this BoardCreateInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this BoardCreateInputV1.
        The ID of the workbook to which the board will be scoped

        :param scoped_to: The scoped_to of this BoardCreateInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def timezone(self):
        """
        Gets the timezone of this BoardCreateInputV1.
        The timezone for the board (IANA timezone identifier)

        :return: The timezone of this BoardCreateInputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this BoardCreateInputV1.
        The timezone for the board (IANA timezone identifier)

        :param timezone: The timezone of this BoardCreateInputV1.
        :type: str
        """
        if timezone is None:
            raise ValueError("Invalid value for `timezone`, must not be `None`")

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardCreateInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemSearchInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset: Optional[str]
    _filters: Optional[List[str]]
    _include_properties: Optional[List[str]]
    _limit: Optional[int]
    _offset: Optional[int]
    _order_by_fields: Optional[List[str]]
    _scope: Optional[List[str]]
    _types: Optional[List[str]]


    def __init__(
        self,
        asset: Optional[str] = None,
        filters: Optional[List[str]] = None,
        include_properties: Optional[List[str]] = None,
        limit: Optional[int] = 40,
        offset: Optional[int] = 0,
        order_by_fields: Optional[List[str]] = None,
        scope: Optional[List[str]] = None,
        types: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def asset(self) -> Optional[str]: ...

    @asset.setter
    def asset(self, asset: Optional[str]) -> None: ...

    @property
    def filters(self) -> Optional[List[str]]: ...

    @filters.setter
    def filters(self, filters: Optional[List[str]]) -> None: ...

    @property
    def include_properties(self) -> Optional[List[str]]: ...

    @include_properties.setter
    def include_properties(self, include_properties: Optional[List[str]]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def offset(self) -> Optional[int]: ...

    @offset.setter
    def offset(self, offset: Optional[int]) -> None: ...

    @property
    def order_by_fields(self) -> Optional[List[str]]: ...

    @order_by_fields.setter
    def order_by_fields(self, order_by_fields: Optional[List[str]]) -> None: ...

    @property
    def scope(self) -> Optional[List[str]]: ...

    @scope.setter
    def scope(self, scope: Optional[List[str]]) -> None: ...

    @property
    def types(self) -> Optional[List[str]]: ...

    @types.setter
    def types(self, types: Optional[List[str]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AssetGroupAssetInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _children: Optional[List[FormulaItemInputV1]]
    _data_id: Optional[str]
    _description: Optional[str]
    _host_id: Optional[str]
    _id: Optional[str]
    _manually_added: Optional[str]
    _name: str
    _properties: Optional[List[ScalarPropertyV1]]
    _scoped_to: Optional[str]
    _security_string: Optional[str]
    _source_security_string: Optional[str]
    _sync_token: Optional[str]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        children: Optional[List[FormulaItemInputV1]] = None,
        data_id: Optional[str] = None,
        description: Optional[str] = None,
        host_id: Optional[str] = None,
        id: Optional[str] = None,
        manually_added: Optional[str] = None,
        name: Optional[str] = None,
        properties: Optional[List[ScalarPropertyV1]] = None,
        scoped_to: Optional[str] = None,
        security_string: Optional[str] = None,
        source_security_string: Optional[str] = None,
        sync_token: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def children(self) -> Optional[List[FormulaItemInputV1]]: ...

    @children.setter
    def children(self, children: Optional[List[FormulaItemInputV1]]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def host_id(self) -> Optional[str]: ...

    @host_id.setter
    def host_id(self, host_id: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def manually_added(self) -> Optional[str]: ...

    @manually_added.setter
    def manually_added(self, manually_added: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @properties.setter
    def properties(self, properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def security_string(self) -> Optional[str]: ...

    @security_string.setter
    def security_string(self, security_string: Optional[str]) -> None: ...

    @property
    def source_security_string(self) -> Optional[str]: ...

    @source_security_string.setter
    def source_security_string(self, source_security_string: Optional[str]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardTimeframeComparisonTileOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _skip_reason: Optional[str]
    _skipped: bool
    _tile_id: str
    _tile_name: str
    _tile_type: str
    _variations: List[BoardTimeframeComparisonMetricOutputV1]


    def __init__(
        self,
        skip_reason: Optional[str] = None,
        skipped: Optional[bool] = None,
        tile_id: Optional[str] = None,
        tile_name: Optional[str] = None,
        tile_type: Optional[str] = None,
        variations: Optional[List[BoardTimeframeComparisonMetricOutputV1]] = None,
    ) -> None: ...

    @property
    def skip_reason(self) -> Optional[str]: ...

    @skip_reason.setter
    def skip_reason(self, skip_reason: Optional[str]) -> None: ...

    @property
    def skipped(self) -> bool: ...

    @skipped.setter
    def skipped(self, skipped: bool) -> None: ...

    @property
    def tile_id(self) -> str: ...

    @tile_id.setter
    def tile_id(self, tile_id: str) -> None: ...

    @property
    def tile_name(self) -> str: ...

    @tile_name.setter
    def tile_name(self, tile_name: str) -> None: ...

    @property
    def tile_type(self) -> str: ...

    @tile_type.setter
    def tile_type(self, tile_type: str) -> None: ...

    @property
    def variations(self) -> List[BoardTimeframeComparisonMetricOutputV1]: ...

    @variations.setter
    def variations(self, variations: List[BoardTimeframeComparisonMetricOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FolderOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _ancestors: Optional[List[ItemPreviewV1]]
    _created_at: Optional[str]
    _creator: Optional[IdentityPreviewV1]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _id: str
    _is_archived: Optional[bool]
    _is_organization_folder: Optional[bool]
    _is_redacted: Optional[bool]
    _marked_as_favorite: Optional[bool]
    _name: str
    _organization_folder: Optional[bool]
    _owner: Optional[IdentityPreviewV1]
    _parent_folder_id: Optional[str]
    _status_message: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _updated_at: Optional[str]


    def __init__(
        self,
        ancestors: Optional[List[ItemPreviewV1]] = None,
        created_at: Optional[str] = None,
        creator: Optional[IdentityPreviewV1] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_organization_folder: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        marked_as_favorite: Optional[bool] = False,
        name: Optional[str] = None,
        organization_folder: Optional[bool] = None,
        owner: Optional[IdentityPreviewV1] = None,
        parent_folder_id: Optional[str] = None,
        status_message: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def ancestors(self) -> Optional[List[ItemPreviewV1]]: ...

    @ancestors.setter
    def ancestors(self, ancestors: Optional[List[ItemPreviewV1]]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator(self) -> Optional[IdentityPreviewV1]: ...

    @creator.setter
    def creator(self, creator: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_organization_folder(self) -> Optional[bool]: ...

    @is_organization_folder.setter
    def is_organization_folder(self, is_organization_folder: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def marked_as_favorite(self) -> Optional[bool]: ...

    @marked_as_favorite.setter
    def marked_as_favorite(self, marked_as_favorite: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def organization_folder(self) -> Optional[bool]: ...

    @organization_folder.setter
    def organization_folder(self, organization_folder: Optional[bool]) -> None: ...

    @property
    def owner(self) -> Optional[IdentityPreviewV1]: ...

    @owner.setter
    def owner(self, owner: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def parent_folder_id(self) -> Optional[str]: ...

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class PropertySearchV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _ancestor_id: Optional[str]
    _ancestor_predicates: Optional[List[AncestorFilterInputV1]]
    _folder_id: Optional[str]
    _is_include: bool
    _predicates: Optional[List[PropertyFilterInputV1]]
    _search_order: Optional[int]
    _search_type: str
    _types: List[str]


    def __init__(
        self,
        ancestor_id: Optional[str] = None,
        ancestor_predicates: Optional[List[AncestorFilterInputV1]] = None,
        folder_id: Optional[str] = None,
        is_include: Optional[bool] = None,
        predicates: Optional[List[PropertyFilterInputV1]] = None,
        search_order: Optional[int] = None,
        search_type: Optional[str] = None,
        types: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def ancestor_id(self) -> Optional[str]: ...

    @ancestor_id.setter
    def ancestor_id(self, ancestor_id: Optional[str]) -> None: ...

    @property
    def ancestor_predicates(self) -> Optional[List[AncestorFilterInputV1]]: ...

    @ancestor_predicates.setter
    def ancestor_predicates(self, ancestor_predicates: Optional[List[AncestorFilterInputV1]]) -> None: ...

    @property
    def folder_id(self) -> Optional[str]: ...

    @folder_id.setter
    def folder_id(self, folder_id: Optional[str]) -> None: ...

    @property
    def is_include(self) -> bool: ...

    @is_include.setter
    def is_include(self, is_include: bool) -> None: ...

    @property
    def predicates(self) -> Optional[List[PropertyFilterInputV1]]: ...

    @predicates.setter
    def predicates(self, predicates: Optional[List[PropertyFilterInputV1]]) -> None: ...

    @property
    def search_order(self) -> Optional[int]: ...

    @search_order.setter
    def search_order(self, search_order: Optional[int]) -> None: ...

    @property
    def search_type(self) -> str: ...

    @search_type.setter
    def search_type(self, search_type: str) -> None: ...

    @property
    def types(self) -> List[str]: ...

    @types.setter
    def types(self, types: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LabelHierarchyInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'depth': 'int',
        'include_archived': 'bool',
        'max_nodes': 'int',
        'pairs': 'list[CategoryLabelPairInputV1]'
    }

    attribute_map = {
        'depth': 'depth',
        'include_archived': 'includeArchived',
        'max_nodes': 'maxNodes',
        'pairs': 'pairs'
    }

    def __init__(self, depth=10, include_archived=False, max_nodes=1000, pairs=None):
        """
        LabelHierarchyInputV1 - a model defined in Swagger
        """

        self._depth = None
        self._include_archived = None
        self._max_nodes = None
        self._pairs = None

        if depth is not None:
          self.depth = depth
        if include_archived is not None:
          self.include_archived = include_archived
        if max_nodes is not None:
          self.max_nodes = max_nodes
        if pairs is not None:
          self.pairs = pairs

    @property
    def depth(self):
        """
        Gets the depth of this LabelHierarchyInputV1.
        Maximum depth to traverse in the hierarchy. Must be between 1 and 50. Default is 10.

        :return: The depth of this LabelHierarchyInputV1.
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """
        Sets the depth of this LabelHierarchyInputV1.
        Maximum depth to traverse in the hierarchy. Must be between 1 and 50. Default is 10.

        :param depth: The depth of this LabelHierarchyInputV1.
        :type: int
        """

        self._depth = depth

    @property
    def include_archived(self):
        """
        Gets the include_archived of this LabelHierarchyInputV1.
        If true, include archived labels and categories in the results. Default is false.

        :return: The include_archived of this LabelHierarchyInputV1.
        :rtype: bool
        """
        return self._include_archived

    @include_archived.setter
    def include_archived(self, include_archived):
        """
        Sets the include_archived of this LabelHierarchyInputV1.
        If true, include archived labels and categories in the results. Default is false.

        :param include_archived: The include_archived of this LabelHierarchyInputV1.
        :type: bool
        """

        self._include_archived = include_archived

    @property
    def max_nodes(self):
        """
        Gets the max_nodes of this LabelHierarchyInputV1.
        Maximum total nodes returned across all roots. Must be between 1 and 10000. Default is 1000.

        :return: The max_nodes of this LabelHierarchyInputV1.
        :rtype: int
        """
        return self._max_nodes

    @max_nodes.setter
    def max_nodes(self, max_nodes):
        """
        Sets the max_nodes of this LabelHierarchyInputV1.
        Maximum total nodes returned across all roots. Must be between 1 and 10000. Default is 1000.

        :param max_nodes: The max_nodes of this LabelHierarchyInputV1.
        :type: int
        """

        self._max_nodes = max_nodes

    @property
    def pairs(self):
        """
        Gets the pairs of this LabelHierarchyInputV1.
        List of category/label pairs to use as root nodes for the hierarchies

        :return: The pairs of this LabelHierarchyInputV1.
        :rtype: list[CategoryLabelPairInputV1]
        """
        return self._pairs

    @pairs.setter
    def pairs(self, pairs):
        """
        Sets the pairs of this LabelHierarchyInputV1.
        List of category/label pairs to use as root nodes for the hierarchies

        :param pairs: The pairs of this LabelHierarchyInputV1.
        :type: list[CategoryLabelPairInputV1]
        """

        self._pairs = pairs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LabelHierarchyInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConnectionInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _backup_name: Optional[str]
    _datasource_id: Optional[str]
    _enabled: Optional[bool]
    _json: Optional[str]
    _max_concurrent_requests: Optional[int]
    _max_results_per_requests: Optional[int]
    _transforms: Optional[str]


    def __init__(
        self,
        backup_name: Optional[str] = None,
        datasource_id: Optional[str] = None,
        enabled: Optional[bool] = True,
        json: Optional[str] = None,
        max_concurrent_requests: Optional[int] = None,
        max_results_per_requests: Optional[int] = None,
        transforms: Optional[str] = None,
    ) -> None: ...

    @property
    def backup_name(self) -> Optional[str]: ...

    @backup_name.setter
    def backup_name(self, backup_name: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def json(self) -> Optional[str]: ...

    @json.setter
    def json(self, json: Optional[str]) -> None: ...

    @property
    def max_concurrent_requests(self) -> Optional[int]: ...

    @max_concurrent_requests.setter
    def max_concurrent_requests(self, max_concurrent_requests: Optional[int]) -> None: ...

    @property
    def max_results_per_requests(self) -> Optional[int]: ...

    @max_results_per_requests.setter
    def max_results_per_requests(self, max_results_per_requests: Optional[int]) -> None: ...

    @property
    def transforms(self) -> Optional[str]: ...

    @transforms.setter
    def transforms(self, transforms: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TimeInterval(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'duration_time': 'int',
        'empty': 'bool',
        'end_string': 'str',
        'end_time': 'int',
        'limit': 'bool',
        'start_string': 'str',
        'start_time': 'int',
        'time_key': 'int'
    }

    attribute_map = {
        'duration_time': 'durationTime',
        'empty': 'empty',
        'end_string': 'endString',
        'end_time': 'endTime',
        'limit': 'limit',
        'start_string': 'startString',
        'start_time': 'startTime',
        'time_key': 'timeKey'
    }

    def __init__(self, duration_time=None, empty=None, end_string=None, end_time=None, limit=None, start_string=None, start_time=None, time_key=None):
        """
        TimeInterval - a model defined in Swagger
        """

        self._duration_time = None
        self._empty = None
        self._end_string = None
        self._end_time = None
        self._limit = None
        self._start_string = None
        self._start_time = None
        self._time_key = None

        if duration_time is not None:
          self.duration_time = duration_time
        if empty is not None:
          self.empty = empty
        if end_string is not None:
          self.end_string = end_string
        if end_time is not None:
          self.end_time = end_time
        if limit is not None:
          self.limit = limit
        if start_string is not None:
          self.start_string = start_string
        if start_time is not None:
          self.start_time = start_time
        if time_key is not None:
          self.time_key = time_key

    @property
    def duration_time(self):
        """
        Gets the duration_time of this TimeInterval.

        :return: The duration_time of this TimeInterval.
        :rtype: int
        """
        return self._duration_time

    @duration_time.setter
    def duration_time(self, duration_time):
        """
        Sets the duration_time of this TimeInterval.

        :param duration_time: The duration_time of this TimeInterval.
        :type: int
        """

        self._duration_time = duration_time

    @property
    def empty(self):
        """
        Gets the empty of this TimeInterval.

        :return: The empty of this TimeInterval.
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """
        Sets the empty of this TimeInterval.

        :param empty: The empty of this TimeInterval.
        :type: bool
        """

        self._empty = empty

    @property
    def end_string(self):
        """
        Gets the end_string of this TimeInterval.

        :return: The end_string of this TimeInterval.
        :rtype: str
        """
        return self._end_string

    @end_string.setter
    def end_string(self, end_string):
        """
        Sets the end_string of this TimeInterval.

        :param end_string: The end_string of this TimeInterval.
        :type: str
        """

        self._end_string = end_string

    @property
    def end_time(self):
        """
        Gets the end_time of this TimeInterval.

        :return: The end_time of this TimeInterval.
        :rtype: int
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this TimeInterval.

        :param end_time: The end_time of this TimeInterval.
        :type: int
        """

        self._end_time = end_time

    @property
    def limit(self):
        """
        Gets the limit of this TimeInterval.

        :return: The limit of this TimeInterval.
        :rtype: bool
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this TimeInterval.

        :param limit: The limit of this TimeInterval.
        :type: bool
        """

        self._limit = limit

    @property
    def start_string(self):
        """
        Gets the start_string of this TimeInterval.

        :return: The start_string of this TimeInterval.
        :rtype: str
        """
        return self._start_string

    @start_string.setter
    def start_string(self, start_string):
        """
        Sets the start_string of this TimeInterval.

        :param start_string: The start_string of this TimeInterval.
        :type: str
        """

        self._start_string = start_string

    @property
    def start_time(self):
        """
        Gets the start_time of this TimeInterval.

        :return: The start_time of this TimeInterval.
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this TimeInterval.

        :param start_time: The start_time of this TimeInterval.
        :type: int
        """

        self._start_time = start_time

    @property
    def time_key(self):
        """
        Gets the time_key of this TimeInterval.

        :return: The time_key of this TimeInterval.
        :rtype: int
        """
        return self._time_key

    @time_key.setter
    def time_key(self, time_key):
        """
        Sets the time_key of this TimeInterval.

        :param time_key: The time_key of this TimeInterval.
        :type: int
        """

        self._time_key = time_key

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TimeInterval):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SuppressedConditionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition_id': 'str',
        'suppression_end_condition_id': 'str',
        'suppression_end_time': 'str',
        'suppression_start_time': 'str'
    }

    attribute_map = {
        'condition_id': 'conditionId',
        'suppression_end_condition_id': 'suppressionEndConditionId',
        'suppression_end_time': 'suppressionEndTime',
        'suppression_start_time': 'suppressionStartTime'
    }

    def __init__(self, condition_id=None, suppression_end_condition_id=None, suppression_end_time=None, suppression_start_time=None):
        """
        SuppressedConditionOutputV1 - a model defined in Swagger
        """

        self._condition_id = None
        self._suppression_end_condition_id = None
        self._suppression_end_time = None
        self._suppression_start_time = None

        if condition_id is not None:
          self.condition_id = condition_id
        if suppression_end_condition_id is not None:
          self.suppression_end_condition_id = suppression_end_condition_id
        if suppression_end_time is not None:
          self.suppression_end_time = suppression_end_time
        if suppression_start_time is not None:
          self.suppression_start_time = suppression_start_time

    @property
    def condition_id(self):
        """
        Gets the condition_id of this SuppressedConditionOutputV1.
        Condition ID to suppress. A condition is considered suppressed until either the provided end time is reached or the end condition produces a capsule. Suppressed conditions will not produce notifications, but will produce events, albeit with a suppressed property added to allow client applications to filter as needed.

        :return: The condition_id of this SuppressedConditionOutputV1.
        :rtype: str
        """
        return self._condition_id

    @condition_id.setter
    def condition_id(self, condition_id):
        """
        Sets the condition_id of this SuppressedConditionOutputV1.
        Condition ID to suppress. A condition is considered suppressed until either the provided end time is reached or the end condition produces a capsule. Suppressed conditions will not produce notifications, but will produce events, albeit with a suppressed property added to allow client applications to filter as needed.

        :param condition_id: The condition_id of this SuppressedConditionOutputV1.
        :type: str
        """

        self._condition_id = condition_id

    @property
    def suppression_end_condition_id(self):
        """
        Gets the suppression_end_condition_id of this SuppressedConditionOutputV1.
        Condition ID to end the suppression

        :return: The suppression_end_condition_id of this SuppressedConditionOutputV1.
        :rtype: str
        """
        return self._suppression_end_condition_id

    @suppression_end_condition_id.setter
    def suppression_end_condition_id(self, suppression_end_condition_id):
        """
        Sets the suppression_end_condition_id of this SuppressedConditionOutputV1.
        Condition ID to end the suppression

        :param suppression_end_condition_id: The suppression_end_condition_id of this SuppressedConditionOutputV1.
        :type: str
        """

        self._suppression_end_condition_id = suppression_end_condition_id

    @property
    def suppression_end_time(self):
        """
        Gets the suppression_end_time of this SuppressedConditionOutputV1.
        End time of the suppression as an ISO-8601 timestamp

        :return: The suppression_end_time of this SuppressedConditionOutputV1.
        :rtype: str
        """
        return self._suppression_end_time

    @suppression_end_time.setter
    def suppression_end_time(self, suppression_end_time):
        """
        Sets the suppression_end_time of this SuppressedConditionOutputV1.
        End time of the suppression as an ISO-8601 timestamp

        :param suppression_end_time: The suppression_end_time of this SuppressedConditionOutputV1.
        :type: str
        """

        self._suppression_end_time = suppression_end_time

    @property
    def suppression_start_time(self):
        """
        Gets the suppression_start_time of this SuppressedConditionOutputV1.
        Start time of the suppression as an ISO-8601 timestamp

        :return: The suppression_start_time of this SuppressedConditionOutputV1.
        :rtype: str
        """
        return self._suppression_start_time

    @suppression_start_time.setter
    def suppression_start_time(self, suppression_start_time):
        """
        Sets the suppression_start_time of this SuppressedConditionOutputV1.
        Start time of the suppression as an ISO-8601 timestamp

        :param suppression_start_time: The suppression_start_time of this SuppressedConditionOutputV1.
        :type: str
        """

        self._suppression_start_time = suppression_start_time

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SuppressedConditionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ThresholdMetricInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _aggregation_function: Optional[str]
    _bounding_condition: Optional[str]
    _bounding_condition_maximum_duration: Optional[str]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _duration: Optional[str]
    _measured_item: str
    _name: str
    _neutral_color: Optional[str]
    _number_format: Optional[str]
    _period: Optional[str]
    _scoped_to: Optional[str]
    _sync_token: Optional[str]
    _thresholds: Optional[List[str]]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        aggregation_function: Optional[str] = None,
        bounding_condition: Optional[str] = None,
        bounding_condition_maximum_duration: Optional[str] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        duration: Optional[str] = None,
        measured_item: Optional[str] = None,
        name: Optional[str] = None,
        neutral_color: Optional[str] = None,
        number_format: Optional[str] = None,
        period: Optional[str] = None,
        scoped_to: Optional[str] = None,
        sync_token: Optional[str] = None,
        thresholds: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def aggregation_function(self) -> Optional[str]: ...

    @aggregation_function.setter
    def aggregation_function(self, aggregation_function: Optional[str]) -> None: ...

    @property
    def bounding_condition(self) -> Optional[str]: ...

    @bounding_condition.setter
    def bounding_condition(self, bounding_condition: Optional[str]) -> None: ...

    @property
    def bounding_condition_maximum_duration(self) -> Optional[str]: ...

    @bounding_condition_maximum_duration.setter
    def bounding_condition_maximum_duration(self, bounding_condition_maximum_duration: Optional[str]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def duration(self) -> Optional[str]: ...

    @duration.setter
    def duration(self, duration: Optional[str]) -> None: ...

    @property
    def measured_item(self) -> str: ...

    @measured_item.setter
    def measured_item(self, measured_item: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def neutral_color(self) -> Optional[str]: ...

    @neutral_color.setter
    def neutral_color(self, neutral_color: Optional[str]) -> None: ...

    @property
    def number_format(self) -> Optional[str]: ...

    @number_format.setter
    def number_format(self, number_format: Optional[str]) -> None: ...

    @property
    def period(self) -> Optional[str]: ...

    @period.setter
    def period(self, period: Optional[str]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    @property
    def thresholds(self) -> Optional[List[str]]: ...

    @thresholds.setter
    def thresholds(self, thresholds: Optional[List[str]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ListConfigFieldV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _element_config_field: Optional[ConfigFieldV1]
    _element_type: Optional[str]
    _max_item_count: Optional[int]
    _min_item_count: Optional[int]


    def __init__(
        self,
        element_config_field: Optional[ConfigFieldV1] = None,
        element_type: Optional[str] = None,
        max_item_count: Optional[int] = None,
        min_item_count: Optional[int] = None,
    ) -> None: ...

    @property
    def element_config_field(self) -> Optional[ConfigFieldV1]: ...

    @element_config_field.setter
    def element_config_field(self, element_config_field: Optional[ConfigFieldV1]) -> None: ...

    @property
    def element_type(self) -> Optional[str]: ...

    @element_type.setter
    def element_type(self, element_type: Optional[str]) -> None: ...

    @property
    def max_item_count(self) -> Optional[int]: ...

    @max_item_count.setter
    def max_item_count(self, max_item_count: Optional[int]) -> None: ...

    @property
    def min_item_count(self) -> Optional[int]: ...

    @min_item_count.setter
    def min_item_count(self, min_item_count: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class MonitorValues(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _count: Optional[int]
    _fifteen_minute_rate: Optional[float]
    _five_minute_rate: Optional[float]
    _max: Optional[float]
    _mean: Optional[float]
    _min: Optional[float]
    _one_minute_rate: Optional[float]
    _p50: Optional[float]
    _p75: Optional[float]
    _p95: Optional[float]
    _p98: Optional[float]
    _p99: Optional[float]
    _p999: Optional[float]
    _stddev: Optional[float]
    _string_value: Optional[str]
    _value: Optional[float]


    def __init__(
        self,
        count: Optional[int] = None,
        fifteen_minute_rate: Optional[float] = None,
        five_minute_rate: Optional[float] = None,
        max: Optional[float] = None,
        mean: Optional[float] = None,
        min: Optional[float] = None,
        one_minute_rate: Optional[float] = None,
        p50: Optional[float] = None,
        p75: Optional[float] = None,
        p95: Optional[float] = None,
        p98: Optional[float] = None,
        p99: Optional[float] = None,
        p999: Optional[float] = None,
        stddev: Optional[float] = None,
        string_value: Optional[str] = None,
        value: Optional[float] = None,
    ) -> None: ...

    @property
    def count(self) -> Optional[int]: ...

    @count.setter
    def count(self, count: Optional[int]) -> None: ...

    @property
    def fifteen_minute_rate(self) -> Optional[float]: ...

    @fifteen_minute_rate.setter
    def fifteen_minute_rate(self, fifteen_minute_rate: Optional[float]) -> None: ...

    @property
    def five_minute_rate(self) -> Optional[float]: ...

    @five_minute_rate.setter
    def five_minute_rate(self, five_minute_rate: Optional[float]) -> None: ...

    @property
    def max(self) -> Optional[float]: ...

    @max.setter
    def max(self, max: Optional[float]) -> None: ...

    @property
    def mean(self) -> Optional[float]: ...

    @mean.setter
    def mean(self, mean: Optional[float]) -> None: ...

    @property
    def min(self) -> Optional[float]: ...

    @min.setter
    def min(self, min: Optional[float]) -> None: ...

    @property
    def one_minute_rate(self) -> Optional[float]: ...

    @one_minute_rate.setter
    def one_minute_rate(self, one_minute_rate: Optional[float]) -> None: ...

    @property
    def p50(self) -> Optional[float]: ...

    @p50.setter
    def p50(self, p50: Optional[float]) -> None: ...

    @property
    def p75(self) -> Optional[float]: ...

    @p75.setter
    def p75(self, p75: Optional[float]) -> None: ...

    @property
    def p95(self) -> Optional[float]: ...

    @p95.setter
    def p95(self, p95: Optional[float]) -> None: ...

    @property
    def p98(self) -> Optional[float]: ...

    @p98.setter
    def p98(self, p98: Optional[float]) -> None: ...

    @property
    def p99(self) -> Optional[float]: ...

    @p99.setter
    def p99(self, p99: Optional[float]) -> None: ...

    @property
    def p999(self) -> Optional[float]: ...

    @p999.setter
    def p999(self, p999: Optional[float]) -> None: ...

    @property
    def stddev(self) -> Optional[float]: ...

    @stddev.setter
    def stddev(self, stddev: Optional[float]) -> None: ...

    @property
    def string_value(self) -> Optional[str]: ...

    @string_value.setter
    def string_value(self, string_value: Optional[str]) -> None: ...

    @property
    def value(self) -> Optional[float]: ...

    @value.setter
    def value(self, value: Optional[float]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatafileInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _append: Optional[bool]
    _condition_name: Optional[str]
    _data_id: Optional[str]
    _day_first_default: Optional[bool]
    _description: Optional[str]
    _description_row: Optional[int]
    _end_column_index: Optional[int]
    _end_column_name: Optional[str]
    _field_delimiter: Optional[str]
    _filename: Optional[str]
    _first_data_row: Optional[int]
    _host_id: Optional[str]
    _interpolation_method: Optional[str]
    _interpolation_method_row: Optional[int]
    _item_type: Optional[str]
    _key_column_index: Optional[int]
    _key_column_name: Optional[str]
    _key_format: Optional[str]
    _lenient_daylight_savings: Optional[bool]
    _maximum_duration: Optional[str]
    _maximum_interpolation: Optional[str]
    _maximum_interpolation_row: Optional[int]
    _name: str
    _name_prefix: Optional[str]
    _name_row: Optional[int]
    _name_suffix: Optional[str]
    _properties: Optional[List[ScalarPropertyV1]]
    _scoped_to: Optional[str]
    _time_zone: Optional[str]
    _upload_filename: str
    _validation_mode: Optional[str]
    _value_column_indices: Optional[str]
    _value_column_names: Optional[str]
    _value_uom: Optional[str]
    _value_uom_row: Optional[int]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        append: Optional[bool] = False,
        condition_name: Optional[str] = None,
        data_id: Optional[str] = None,
        day_first_default: Optional[bool] = False,
        description: Optional[str] = None,
        description_row: Optional[int] = None,
        end_column_index: Optional[int] = None,
        end_column_name: Optional[str] = None,
        field_delimiter: Optional[str] = None,
        filename: Optional[str] = None,
        first_data_row: Optional[int] = None,
        host_id: Optional[str] = None,
        interpolation_method: Optional[str] = None,
        interpolation_method_row: Optional[int] = None,
        item_type: Optional[str] = None,
        key_column_index: Optional[int] = None,
        key_column_name: Optional[str] = None,
        key_format: Optional[str] = None,
        lenient_daylight_savings: Optional[bool] = False,
        maximum_duration: Optional[str] = None,
        maximum_interpolation: Optional[str] = None,
        maximum_interpolation_row: Optional[int] = None,
        name: Optional[str] = None,
        name_prefix: Optional[str] = None,
        name_row: Optional[int] = None,
        name_suffix: Optional[str] = None,
        properties: Optional[List[ScalarPropertyV1]] = None,
        scoped_to: Optional[str] = None,
        time_zone: Optional[str] = None,
        upload_filename: Optional[str] = None,
        validation_mode: Optional[str] = None,
        value_column_indices: Optional[str] = None,
        value_column_names: Optional[str] = None,
        value_uom: Optional[str] = None,
        value_uom_row: Optional[int] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def append(self) -> Optional[bool]: ...

    @append.setter
    def append(self, append: Optional[bool]) -> None: ...

    @property
    def condition_name(self) -> Optional[str]: ...

    @condition_name.setter
    def condition_name(self, condition_name: Optional[str]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def day_first_default(self) -> Optional[bool]: ...

    @day_first_default.setter
    def day_first_default(self, day_first_default: Optional[bool]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def description_row(self) -> Optional[int]: ...

    @description_row.setter
    def description_row(self, description_row: Optional[int]) -> None: ...

    @property
    def end_column_index(self) -> Optional[int]: ...

    @end_column_index.setter
    def end_column_index(self, end_column_index: Optional[int]) -> None: ...

    @property
    def end_column_name(self) -> Optional[str]: ...

    @end_column_name.setter
    def end_column_name(self, end_column_name: Optional[str]) -> None: ...

    @property
    def field_delimiter(self) -> Optional[str]: ...

    @field_delimiter.setter
    def field_delimiter(self, field_delimiter: Optional[str]) -> None: ...

    @property
    def filename(self) -> Optional[str]: ...

    @filename.setter
    def filename(self, filename: Optional[str]) -> None: ...

    @property
    def first_data_row(self) -> Optional[int]: ...

    @first_data_row.setter
    def first_data_row(self, first_data_row: Optional[int]) -> None: ...

    @property
    def host_id(self) -> Optional[str]: ...

    @host_id.setter
    def host_id(self, host_id: Optional[str]) -> None: ...

    @property
    def interpolation_method(self) -> Optional[str]: ...

    @interpolation_method.setter
    def interpolation_method(self, interpolation_method: Optional[str]) -> None: ...

    @property
    def interpolation_method_row(self) -> Optional[int]: ...

    @interpolation_method_row.setter
    def interpolation_method_row(self, interpolation_method_row: Optional[int]) -> None: ...

    @property
    def item_type(self) -> Optional[str]: ...

    @item_type.setter
    def item_type(self, item_type: Optional[str]) -> None: ...

    @property
    def key_column_index(self) -> Optional[int]: ...

    @key_column_index.setter
    def key_column_index(self, key_column_index: Optional[int]) -> None: ...

    @property
    def key_column_name(self) -> Optional[str]: ...

    @key_column_name.setter
    def key_column_name(self, key_column_name: Optional[str]) -> None: ...

    @property
    def key_format(self) -> Optional[str]: ...

    @key_format.setter
    def key_format(self, key_format: Optional[str]) -> None: ...

    @property
    def lenient_daylight_savings(self) -> Optional[bool]: ...

    @lenient_daylight_savings.setter
    def lenient_daylight_savings(self, lenient_daylight_savings: Optional[bool]) -> None: ...

    @property
    def maximum_duration(self) -> Optional[str]: ...

    @maximum_duration.setter
    def maximum_duration(self, maximum_duration: Optional[str]) -> None: ...

    @property
    def maximum_interpolation(self) -> Optional[str]: ...

    @maximum_interpolation.setter
    def maximum_interpolation(self, maximum_interpolation: Optional[str]) -> None: ...

    @property
    def maximum_interpolation_row(self) -> Optional[int]: ...

    @maximum_interpolation_row.setter
    def maximum_interpolation_row(self, maximum_interpolation_row: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def name_prefix(self) -> Optional[str]: ...

    @name_prefix.setter
    def name_prefix(self, name_prefix: Optional[str]) -> None: ...

    @property
    def name_row(self) -> Optional[int]: ...

    @name_row.setter
    def name_row(self, name_row: Optional[int]) -> None: ...

    @property
    def name_suffix(self) -> Optional[str]: ...

    @name_suffix.setter
    def name_suffix(self, name_suffix: Optional[str]) -> None: ...

    @property
    def properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @properties.setter
    def properties(self, properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def time_zone(self) -> Optional[str]: ...

    @time_zone.setter
    def time_zone(self, time_zone: Optional[str]) -> None: ...

    @property
    def upload_filename(self) -> str: ...

    @upload_filename.setter
    def upload_filename(self, upload_filename: str) -> None: ...

    @property
    def validation_mode(self) -> Optional[str]: ...

    @validation_mode.setter
    def validation_mode(self, validation_mode: Optional[str]) -> None: ...

    @property
    def value_column_indices(self) -> Optional[str]: ...

    @value_column_indices.setter
    def value_column_indices(self, value_column_indices: Optional[str]) -> None: ...

    @property
    def value_column_names(self) -> Optional[str]: ...

    @value_column_names.setter
    def value_column_names(self, value_column_names: Optional[str]) -> None: ...

    @property
    def value_uom(self) -> Optional[str]: ...

    @value_uom.setter
    def value_uom(self, value_uom: Optional[str]) -> None: ...

    @property
    def value_uom_row(self) -> Optional[int]: ...

    @value_uom_row.setter
    def value_uom_row(self, value_uom_row: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class VersionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _created_at: Optional[str]
    _creator: ItemPreviewV1
    _notes: str
    _version: int
    _version_source: Optional[VersionSourceOutputV1]
    _version_source_item: Optional[VersionSourceItemOutputV1]
    _versioned_item: ItemPreviewV1


    def __init__(
        self,
        created_at: Optional[str] = None,
        creator: Optional[ItemPreviewV1] = None,
        notes: Optional[str] = None,
        version: Optional[int] = None,
        version_source: Optional[VersionSourceOutputV1] = None,
        version_source_item: Optional[VersionSourceItemOutputV1] = None,
        versioned_item: Optional[ItemPreviewV1] = None,
    ) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator(self) -> ItemPreviewV1: ...

    @creator.setter
    def creator(self, creator: ItemPreviewV1) -> None: ...

    @property
    def notes(self) -> str: ...

    @notes.setter
    def notes(self, notes: str) -> None: ...

    @property
    def version(self) -> int: ...

    @version.setter
    def version(self, version: int) -> None: ...

    @property
    def version_source(self) -> Optional[VersionSourceOutputV1]: ...

    @version_source.setter
    def version_source(self, version_source: Optional[VersionSourceOutputV1]) -> None: ...

    @property
    def version_source_item(self) -> Optional[VersionSourceItemOutputV1]: ...

    @version_source_item.setter
    def version_source_item(self, version_source_item: Optional[VersionSourceItemOutputV1]) -> None: ...

    @property
    def versioned_item(self) -> ItemPreviewV1: ...

    @versioned_item.setter
    def versioned_item(self, versioned_item: ItemPreviewV1) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class StoredTablesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_stored_table_from_csv(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def create_stored_table_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_column_from_stored_table(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def delete_column_from_stored_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_stored_table_rows(
        self,
        **kwargs: Any,
    ) -> DeleteRowsOutputV1: ...

    def delete_stored_table_rows_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_stored_table(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def get_stored_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def import_stored_table_csv(
        self,
        **kwargs: Any,
    ) -> ImportTableCSVOutputV1: ...

    def import_stored_table_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def modify_column_in_stored_table(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def modify_column_in_stored_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_column_data(
        self,
        **kwargs: Any,
    ) -> UpdatedRowsOutputV1: ...

    def update_column_data_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_stored_table_from_csv(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def update_stored_table_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelTableApplicationsOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'mappings': 'list[ModelApplicationMappingV1]',
        'model_container_id': 'str',
        'model_guid': 'str',
        'model_name': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'mappings': 'mappings',
        'model_container_id': 'modelContainerId',
        'model_guid': 'modelGuid',
        'model_name': 'modelName',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, mappings=None, model_container_id=None, model_guid=None, model_name=None, updated_at=None):
        """
        ModelTableApplicationsOutputV1 - a model defined in Swagger
        """

        self._id = None
        self._mappings = None
        self._model_container_id = None
        self._model_guid = None
        self._model_name = None
        self._updated_at = None

        if id is not None:
          self.id = id
        if mappings is not None:
          self.mappings = mappings
        if model_container_id is not None:
          self.model_container_id = model_container_id
        if model_guid is not None:
          self.model_guid = model_guid
        if model_name is not None:
          self.model_name = model_name
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def id(self):
        """
        Gets the id of this ModelTableApplicationsOutputV1.
        Model Application ID

        :return: The id of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ModelTableApplicationsOutputV1.
        Model Application ID

        :param id: The id of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._id = id

    @property
    def mappings(self):
        """
        Gets the mappings of this ModelTableApplicationsOutputV1.
        Mapping of column definition IDs or literals to a feature ID

        :return: The mappings of this ModelTableApplicationsOutputV1.
        :rtype: list[ModelApplicationMappingV1]
        """
        return self._mappings

    @mappings.setter
    def mappings(self, mappings):
        """
        Sets the mappings of this ModelTableApplicationsOutputV1.
        Mapping of column definition IDs or literals to a feature ID

        :param mappings: The mappings of this ModelTableApplicationsOutputV1.
        :type: list[ModelApplicationMappingV1]
        """

        self._mappings = mappings

    @property
    def model_container_id(self):
        """
        Gets the model_container_id of this ModelTableApplicationsOutputV1.
        ID of the ModelContainer that is the canonical identity for the model

        :return: The model_container_id of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._model_container_id

    @model_container_id.setter
    def model_container_id(self, model_container_id):
        """
        Sets the model_container_id of this ModelTableApplicationsOutputV1.
        ID of the ModelContainer that is the canonical identity for the model

        :param model_container_id: The model_container_id of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._model_container_id = model_container_id

    @property
    def model_guid(self):
        """
        Gets the model_guid of this ModelTableApplicationsOutputV1.
        Model GUID

        :return: The model_guid of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._model_guid

    @model_guid.setter
    def model_guid(self, model_guid):
        """
        Sets the model_guid of this ModelTableApplicationsOutputV1.
        Model GUID

        :param model_guid: The model_guid of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._model_guid = model_guid

    @property
    def model_name(self):
        """
        Gets the model_name of this ModelTableApplicationsOutputV1.
        Model Name

        :return: The model_name of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """
        Sets the model_name of this ModelTableApplicationsOutputV1.
        Model Name

        :param model_name: The model_name of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._model_name = model_name

    @property
    def updated_at(self):
        """
        Gets the updated_at of this ModelTableApplicationsOutputV1.
        The UTC timestamp when the model table application was last updated

        :return: The updated_at of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this ModelTableApplicationsOutputV1.
        The UTC timestamp when the model table application was last updated

        :param updated_at: The updated_at of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelTableApplicationsOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class AnnotationsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_annotation(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_annotation_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def cors_image_proxy(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def cors_image_proxy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_annotation(
        self,
        **kwargs: Any,
    ) -> AnnotationOutputV1: ...

    def create_annotation_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_image(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_image_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_annotation(
        self,
        **kwargs: Any,
    ) -> AnnotationOutputV1: ...

    def get_annotation_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_annotations(
        self,
        **kwargs: Any,
    ) -> AnnotationListOutputV1: ...

    def get_annotations_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_image(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def get_image_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def migrate_annotation_to_ck_editor(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def migrate_annotation_to_ck_editor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def publish_report(
        self,
        **kwargs: Any,
    ) -> AnnotationOutputV1: ...

    def publish_report_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_annotation(
        self,
        **kwargs: Any,
    ) -> AnnotationOutputV1: ...

    def update_annotation_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def upload_image(
        self,
        **kwargs: Any,
    ) -> AnnotationImageLinkOutputV1: ...

    def upload_image_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelApplicationErrorOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'feature_id': 'str',
        'message': 'str',
        'message_arguments': 'dict(str, str)',
        'message_number': 'int',
        'model_id': 'str',
        'rule_id': 'str'
    }

    attribute_map = {
        'feature_id': 'featureId',
        'message': 'message',
        'message_arguments': 'messageArguments',
        'message_number': 'messageNumber',
        'model_id': 'modelId',
        'rule_id': 'ruleId'
    }

    def __init__(self, feature_id=None, message=None, message_arguments=None, message_number=None, model_id=None, rule_id=None):
        """
        ModelApplicationErrorOutputV1 - a model defined in Swagger
        """

        self._feature_id = None
        self._message = None
        self._message_arguments = None
        self._message_number = None
        self._model_id = None
        self._rule_id = None

        if feature_id is not None:
          self.feature_id = feature_id
        if message is not None:
          self.message = message
        if message_arguments is not None:
          self.message_arguments = message_arguments
        if message_number is not None:
          self.message_number = message_number
        if model_id is not None:
          self.model_id = model_id
        if rule_id is not None:
          self.rule_id = rule_id

    @property
    def feature_id(self):
        """
        Gets the feature_id of this ModelApplicationErrorOutputV1.
        UUID of the feature being evaluated when the error occurred.

        :return: The feature_id of this ModelApplicationErrorOutputV1.
        :rtype: str
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """
        Sets the feature_id of this ModelApplicationErrorOutputV1.
        UUID of the feature being evaluated when the error occurred.

        :param feature_id: The feature_id of this ModelApplicationErrorOutputV1.
        :type: str
        """

        self._feature_id = feature_id

    @property
    def message(self):
        """
        Gets the message of this ModelApplicationErrorOutputV1.
        Human-readable message describing the error.

        :return: The message of this ModelApplicationErrorOutputV1.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ModelApplicationErrorOutputV1.
        Human-readable message describing the error.

        :param message: The message of this ModelApplicationErrorOutputV1.
        :type: str
        """

        self._message = message

    @property
    def message_arguments(self):
        """
        Gets the message_arguments of this ModelApplicationErrorOutputV1.
        Arguments for the message, if applicable.

        :return: The message_arguments of this ModelApplicationErrorOutputV1.
        :rtype: dict(str, str)
        """
        return self._message_arguments

    @message_arguments.setter
    def message_arguments(self, message_arguments):
        """
        Sets the message_arguments of this ModelApplicationErrorOutputV1.
        Arguments for the message, if applicable.

        :param message_arguments: The message_arguments of this ModelApplicationErrorOutputV1.
        :type: dict(str, str)
        """

        self._message_arguments = message_arguments

    @property
    def message_number(self):
        """
        Gets the message_number of this ModelApplicationErrorOutputV1.
        Message number for localization purposes.

        :return: The message_number of this ModelApplicationErrorOutputV1.
        :rtype: int
        """
        return self._message_number

    @message_number.setter
    def message_number(self, message_number):
        """
        Sets the message_number of this ModelApplicationErrorOutputV1.
        Message number for localization purposes.

        :param message_number: The message_number of this ModelApplicationErrorOutputV1.
        :type: int
        """

        self._message_number = message_number

    @property
    def model_id(self):
        """
        Gets the model_id of this ModelApplicationErrorOutputV1.
        UUID of the model that produced the error.

        :return: The model_id of this ModelApplicationErrorOutputV1.
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """
        Sets the model_id of this ModelApplicationErrorOutputV1.
        UUID of the model that produced the error.

        :param model_id: The model_id of this ModelApplicationErrorOutputV1.
        :type: str
        """

        self._model_id = model_id

    @property
    def rule_id(self):
        """
        Gets the rule_id of this ModelApplicationErrorOutputV1.
        UUID of the specific rule that failed or produced the error.

        :return: The rule_id of this ModelApplicationErrorOutputV1.
        :rtype: str
        """
        return self._rule_id

    @rule_id.setter
    def rule_id(self, rule_id):
        """
        Sets the rule_id of this ModelApplicationErrorOutputV1.
        UUID of the specific rule that failed or produced the error.

        :param rule_id: The rule_id of this ModelApplicationErrorOutputV1.
        :type: str
        """

        self._rule_id = rule_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelApplicationErrorOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class IssueSummaryOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _installed_on: str
    _issue_type: str
    _key: int
    _summary: str
    _version: str


    def __init__(
        self,
        installed_on: Optional[str] = None,
        issue_type: Optional[str] = None,
        key: Optional[int] = None,
        summary: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def installed_on(self) -> str: ...

    @installed_on.setter
    def installed_on(self, installed_on: str) -> None: ...

    @property
    def issue_type(self) -> str: ...

    @issue_type.setter
    def issue_type(self, issue_type: str) -> None: ...

    @property
    def key(self) -> int: ...

    @key.setter
    def key(self, key: int) -> None: ...

    @property
    def summary(self) -> str: ...

    @summary.setter
    def summary(self, summary: str) -> None: ...

    @property
    def version(self) -> str: ...

    @version.setter
    def version(self, version: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTimeframeComparisonResultOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'baseline_range': 'str',
        'board_id': 'str',
        'board_name': 'str',
        'current_range': 'str',
        'tiles': 'list[BoardTimeframeComparisonTileOutputV1]',
        'tiles_analyzed': 'int',
        'tiles_skipped': 'int'
    }

    attribute_map = {
        'baseline_range': 'baselineRange',
        'board_id': 'boardId',
        'board_name': 'boardName',
        'current_range': 'currentRange',
        'tiles': 'tiles',
        'tiles_analyzed': 'tilesAnalyzed',
        'tiles_skipped': 'tilesSkipped'
    }

    def __init__(self, baseline_range=None, board_id=None, board_name=None, current_range=None, tiles=None, tiles_analyzed=None, tiles_skipped=None):
        """
        BoardTimeframeComparisonResultOutputV1 - a model defined in Swagger
        """

        self._baseline_range = None
        self._board_id = None
        self._board_name = None
        self._current_range = None
        self._tiles = None
        self._tiles_analyzed = None
        self._tiles_skipped = None

        if baseline_range is not None:
          self.baseline_range = baseline_range
        if board_id is not None:
          self.board_id = board_id
        if board_name is not None:
          self.board_name = board_name
        if current_range is not None:
          self.current_range = current_range
        if tiles is not None:
          self.tiles = tiles
        if tiles_analyzed is not None:
          self.tiles_analyzed = tiles_analyzed
        if tiles_skipped is not None:
          self.tiles_skipped = tiles_skipped

    @property
    def baseline_range(self):
        """
        Gets the baseline_range of this BoardTimeframeComparisonResultOutputV1.
        Baseline time range description

        :return: The baseline_range of this BoardTimeframeComparisonResultOutputV1.
        :rtype: str
        """
        return self._baseline_range

    @baseline_range.setter
    def baseline_range(self, baseline_range):
        """
        Sets the baseline_range of this BoardTimeframeComparisonResultOutputV1.
        Baseline time range description

        :param baseline_range: The baseline_range of this BoardTimeframeComparisonResultOutputV1.
        :type: str
        """
        if baseline_range is None:
            raise ValueError("Invalid value for `baseline_range`, must not be `None`")

        self._baseline_range = baseline_range

    @property
    def board_id(self):
        """
        Gets the board_id of this BoardTimeframeComparisonResultOutputV1.
        Board id

        :return: The board_id of this BoardTimeframeComparisonResultOutputV1.
        :rtype: str
        """
        return self._board_id

    @board_id.setter
    def board_id(self, board_id):
        """
        Sets the board_id of this BoardTimeframeComparisonResultOutputV1.
        Board id

        :param board_id: The board_id of this BoardTimeframeComparisonResultOutputV1.
        :type: str
        """
        if board_id is None:
            raise ValueError("Invalid value for `board_id`, must not be `None`")

        self._board_id = board_id

    @property
    def board_name(self):
        """
        Gets the board_name of this BoardTimeframeComparisonResultOutputV1.
        Board name

        :return: The board_name of this BoardTimeframeComparisonResultOutputV1.
        :rtype: str
        """
        return self._board_name

    @board_name.setter
    def board_name(self, board_name):
        """
        Sets the board_name of this BoardTimeframeComparisonResultOutputV1.
        Board name

        :param board_name: The board_name of this BoardTimeframeComparisonResultOutputV1.
        :type: str
        """
        if board_name is None:
            raise ValueError("Invalid value for `board_name`, must not be `None`")

        self._board_name = board_name

    @property
    def current_range(self):
        """
        Gets the current_range of this BoardTimeframeComparisonResultOutputV1.
        Current time range description

        :return: The current_range of this BoardTimeframeComparisonResultOutputV1.
        :rtype: str
        """
        return self._current_range

    @current_range.setter
    def current_range(self, current_range):
        """
        Sets the current_range of this BoardTimeframeComparisonResultOutputV1.
        Current time range description

        :param current_range: The current_range of this BoardTimeframeComparisonResultOutputV1.
        :type: str
        """
        if current_range is None:
            raise ValueError("Invalid value for `current_range`, must not be `None`")

        self._current_range = current_range

    @property
    def tiles(self):
        """
        Gets the tiles of this BoardTimeframeComparisonResultOutputV1.
        Per-tile comparison summaries

        :return: The tiles of this BoardTimeframeComparisonResultOutputV1.
        :rtype: list[BoardTimeframeComparisonTileOutputV1]
        """
        return self._tiles

    @tiles.setter
    def tiles(self, tiles):
        """
        Sets the tiles of this BoardTimeframeComparisonResultOutputV1.
        Per-tile comparison summaries

        :param tiles: The tiles of this BoardTimeframeComparisonResultOutputV1.
        :type: list[BoardTimeframeComparisonTileOutputV1]
        """
        if tiles is None:
            raise ValueError("Invalid value for `tiles`, must not be `None`")

        self._tiles = tiles

    @property
    def tiles_analyzed(self):
        """
        Gets the tiles_analyzed of this BoardTimeframeComparisonResultOutputV1.
        Number of tiles analyzed

        :return: The tiles_analyzed of this BoardTimeframeComparisonResultOutputV1.
        :rtype: int
        """
        return self._tiles_analyzed

    @tiles_analyzed.setter
    def tiles_analyzed(self, tiles_analyzed):
        """
        Sets the tiles_analyzed of this BoardTimeframeComparisonResultOutputV1.
        Number of tiles analyzed

        :param tiles_analyzed: The tiles_analyzed of this BoardTimeframeComparisonResultOutputV1.
        :type: int
        """
        if tiles_analyzed is None:
            raise ValueError("Invalid value for `tiles_analyzed`, must not be `None`")

        self._tiles_analyzed = tiles_analyzed

    @property
    def tiles_skipped(self):
        """
        Gets the tiles_skipped of this BoardTimeframeComparisonResultOutputV1.
        Number of tiles skipped

        :return: The tiles_skipped of this BoardTimeframeComparisonResultOutputV1.
        :rtype: int
        """
        return self._tiles_skipped

    @tiles_skipped.setter
    def tiles_skipped(self, tiles_skipped):
        """
        Sets the tiles_skipped of this BoardTimeframeComparisonResultOutputV1.
        Number of tiles skipped

        :param tiles_skipped: The tiles_skipped of this BoardTimeframeComparisonResultOutputV1.
        :type: int
        """
        if tiles_skipped is None:
            raise ValueError("Invalid value for `tiles_skipped`, must not be `None`")

        self._tiles_skipped = tiles_skipped

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTimeframeComparisonResultOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class StoredTableCSVInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_delimiter': 'str',
        'description': 'str',
        'first_data_row': 'int',
        'header_row': 'int',
        'name': 'str',
        'scoped_to': 'str',
        'source': 'str',
        'upload_filename': 'str'
    }

    attribute_map = {
        'column_delimiter': 'columnDelimiter',
        'description': 'description',
        'first_data_row': 'firstDataRow',
        'header_row': 'headerRow',
        'name': 'name',
        'scoped_to': 'scopedTo',
        'source': 'source',
        'upload_filename': 'uploadFilename'
    }

    def __init__(self, column_delimiter=None, description=None, first_data_row=None, header_row=None, name=None, scoped_to=None, source=None, upload_filename=None):
        """
        StoredTableCSVInputV1 - a model defined in Swagger
        """

        self._column_delimiter = None
        self._description = None
        self._first_data_row = None
        self._header_row = None
        self._name = None
        self._scoped_to = None
        self._source = None
        self._upload_filename = None

        if column_delimiter is not None:
          self.column_delimiter = column_delimiter
        if description is not None:
          self.description = description
        if first_data_row is not None:
          self.first_data_row = first_data_row
        if header_row is not None:
          self.header_row = header_row
        if name is not None:
          self.name = name
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if source is not None:
          self.source = source
        if upload_filename is not None:
          self.upload_filename = upload_filename

    @property
    def column_delimiter(self):
        """
        Gets the column_delimiter of this StoredTableCSVInputV1.
        The character used as the CSV field delimiter. The possibilities are comma, semicolon, and tab

        :return: The column_delimiter of this StoredTableCSVInputV1.
        :rtype: str
        """
        return self._column_delimiter

    @column_delimiter.setter
    def column_delimiter(self, column_delimiter):
        """
        Sets the column_delimiter of this StoredTableCSVInputV1.
        The character used as the CSV field delimiter. The possibilities are comma, semicolon, and tab

        :param column_delimiter: The column_delimiter of this StoredTableCSVInputV1.
        :type: str
        """
        if column_delimiter is None:
            raise ValueError("Invalid value for `column_delimiter`, must not be `None`")

        self._column_delimiter = column_delimiter

    @property
    def description(self):
        """
        Gets the description of this StoredTableCSVInputV1.
        The description of table. 

        :return: The description of this StoredTableCSVInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this StoredTableCSVInputV1.
        The description of table. 

        :param description: The description of this StoredTableCSVInputV1.
        :type: str
        """

        self._description = description

    @property
    def first_data_row(self):
        """
        Gets the first_data_row of this StoredTableCSVInputV1.
        This row and all following rows will be considered as data to be published to the  table definition. The row index is 1-based.

        :return: The first_data_row of this StoredTableCSVInputV1.
        :rtype: int
        """
        return self._first_data_row

    @first_data_row.setter
    def first_data_row(self, first_data_row):
        """
        Sets the first_data_row of this StoredTableCSVInputV1.
        This row and all following rows will be considered as data to be published to the  table definition. The row index is 1-based.

        :param first_data_row: The first_data_row of this StoredTableCSVInputV1.
        :type: int
        """
        if first_data_row is None:
            raise ValueError("Invalid value for `first_data_row`, must not be `None`")

        self._first_data_row = first_data_row

    @property
    def header_row(self):
        """
        Gets the header_row of this StoredTableCSVInputV1.
        Index of row with unique column headers to be used in the creation of table-definition columns. The row index is 1-based.

        :return: The header_row of this StoredTableCSVInputV1.
        :rtype: int
        """
        return self._header_row

    @header_row.setter
    def header_row(self, header_row):
        """
        Sets the header_row of this StoredTableCSVInputV1.
        Index of row with unique column headers to be used in the creation of table-definition columns. The row index is 1-based.

        :param header_row: The header_row of this StoredTableCSVInputV1.
        :type: int
        """
        if header_row is None:
            raise ValueError("Invalid value for `header_row`, must not be `None`")

        self._header_row = header_row

    @property
    def name(self):
        """
        Gets the name of this StoredTableCSVInputV1.
        Human readable name of the table. An input of just whitespaces is equivalent to a null input.

        :return: The name of this StoredTableCSVInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this StoredTableCSVInputV1.
        Human readable name of the table. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this StoredTableCSVInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this StoredTableCSVInputV1.
        The ID of the workbook to which the stored table will be scoped. If not provided, the stored table will have a global scope

        :return: The scoped_to of this StoredTableCSVInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this StoredTableCSVInputV1.
        The ID of the workbook to which the stored table will be scoped. If not provided, the stored table will have a global scope

        :param scoped_to: The scoped_to of this StoredTableCSVInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def source(self):
        """
        Gets the source of this StoredTableCSVInputV1.
        The source creating the table.  Defaults to OTHER.

        :return: The source of this StoredTableCSVInputV1.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this StoredTableCSVInputV1.
        The source creating the table.  Defaults to OTHER.

        :param source: The source of this StoredTableCSVInputV1.
        :type: str
        """

        self._source = source

    @property
    def upload_filename(self):
        """
        Gets the upload_filename of this StoredTableCSVInputV1.
        The Seeq-stored name of the CSV file that is returned from the upload endpoint.

        :return: The upload_filename of this StoredTableCSVInputV1.
        :rtype: str
        """
        return self._upload_filename

    @upload_filename.setter
    def upload_filename(self, upload_filename):
        """
        Sets the upload_filename of this StoredTableCSVInputV1.
        The Seeq-stored name of the CSV file that is returned from the upload endpoint.

        :param upload_filename: The upload_filename of this StoredTableCSVInputV1.
        :type: str
        """
        if upload_filename is None:
            raise ValueError("Invalid value for `upload_filename`, must not be `None`")

        self._upload_filename = upload_filename

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, StoredTableCSVInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class GetAllContextInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment_filter': 'Filter',
        'ids': 'list[ContextIdInputV1]',
        'label_filter': 'Filter',
        'numeric_filter': 'Filter',
        'opaque_filter': 'Filter'
    }

    attribute_map = {
        'comment_filter': 'commentFilter',
        'ids': 'ids',
        'label_filter': 'labelFilter',
        'numeric_filter': 'numericFilter',
        'opaque_filter': 'opaqueFilter'
    }

    def __init__(self, comment_filter=None, ids=None, label_filter=None, numeric_filter=None, opaque_filter=None):
        """
        GetAllContextInputV1 - a model defined in Swagger
        """

        self._comment_filter = None
        self._ids = None
        self._label_filter = None
        self._numeric_filter = None
        self._opaque_filter = None

        if comment_filter is not None:
          self.comment_filter = comment_filter
        if ids is not None:
          self.ids = ids
        if label_filter is not None:
          self.label_filter = label_filter
        if numeric_filter is not None:
          self.numeric_filter = numeric_filter
        if opaque_filter is not None:
          self.opaque_filter = opaque_filter

    @property
    def comment_filter(self):
        """
        Gets the comment_filter of this GetAllContextInputV1.

        :return: The comment_filter of this GetAllContextInputV1.
        :rtype: Filter
        """
        return self._comment_filter

    @comment_filter.setter
    def comment_filter(self, comment_filter):
        """
        Sets the comment_filter of this GetAllContextInputV1.

        :param comment_filter: The comment_filter of this GetAllContextInputV1.
        :type: Filter
        """

        self._comment_filter = comment_filter

    @property
    def ids(self):
        """
        Gets the ids of this GetAllContextInputV1.
        The item IDs to fetch all context for

        :return: The ids of this GetAllContextInputV1.
        :rtype: list[ContextIdInputV1]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """
        Sets the ids of this GetAllContextInputV1.
        The item IDs to fetch all context for

        :param ids: The ids of this GetAllContextInputV1.
        :type: list[ContextIdInputV1]
        """
        if ids is None:
            raise ValueError("Invalid value for `ids`, must not be `None`")

        self._ids = ids

    @property
    def label_filter(self):
        """
        Gets the label_filter of this GetAllContextInputV1.

        :return: The label_filter of this GetAllContextInputV1.
        :rtype: Filter
        """
        return self._label_filter

    @label_filter.setter
    def label_filter(self, label_filter):
        """
        Sets the label_filter of this GetAllContextInputV1.

        :param label_filter: The label_filter of this GetAllContextInputV1.
        :type: Filter
        """

        self._label_filter = label_filter

    @property
    def numeric_filter(self):
        """
        Gets the numeric_filter of this GetAllContextInputV1.

        :return: The numeric_filter of this GetAllContextInputV1.
        :rtype: Filter
        """
        return self._numeric_filter

    @numeric_filter.setter
    def numeric_filter(self, numeric_filter):
        """
        Sets the numeric_filter of this GetAllContextInputV1.

        :param numeric_filter: The numeric_filter of this GetAllContextInputV1.
        :type: Filter
        """

        self._numeric_filter = numeric_filter

    @property
    def opaque_filter(self):
        """
        Gets the opaque_filter of this GetAllContextInputV1.

        :return: The opaque_filter of this GetAllContextInputV1.
        :rtype: Filter
        """
        return self._opaque_filter

    @opaque_filter.setter
    def opaque_filter(self, opaque_filter):
        """
        Sets the opaque_filter of this GetAllContextInputV1.

        :param opaque_filter: The opaque_filter of this GetAllContextInputV1.
        :type: Filter
        """

        self._opaque_filter = opaque_filter

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, GetAllContextInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
